@@ -2,12 +2,11 @@ from __future__ import annotations
 
 import functools
 import inspect
-import typing
 import typing as t
 from os import PathLike
 from starlette import routing
 from starlette.concurrency import run_in_threadpool
-from starlette.routing import Mount, WebSocketRoute, compile_path, get_name, iscoroutinefunction_or_partial
+from starlette.routing import WebSocketRoute, compile_path, get_name, iscoroutinefunction_or_partial
 from starlette.staticfiles import StaticFiles
 from starlette.types import ASGIApp, Receive, Scope, Send
 
@@ -25,7 +24,7 @@ def apply_middleware(app: t.Callable, middleware: t.Sequence[Middleware]) -> ASG
     return app
 
 
-def request_response(func: typing.Callable) -> ASGIApp:
+def request_response(func: t.Callable) -> ASGIApp:
     """
     Takes a function or coroutine `func(request) -> response`,
     and returns an ASGI application.
@@ -48,6 +47,53 @@ def request_response(func: typing.Callable) -> ASGIApp:
     return app
 
 
+class Mount(routing.Mount):
+    def __init__(
+        self,
+        path: str,
+        app: ASGIApp = None,
+        routes: t.Sequence[routing.BaseRoute] = None,
+        name: str = None,
+        *,
+        middleware: t.Sequence[Middleware] = None,
+    ) -> None:
+        assert path == "" or path.startswith("/"), "Routed paths must start with '/'"
+        assert app is not None or routes is not None, "Either 'app=...', or 'routes=' must be specified"
+        self.path = path.rstrip("/")
+        if app is not None:
+            self.app: ASGIApp = app
+            self._routes = getattr(app, 'routes', [])
+        else:
+            self.app = Router(routes=routes)
+            self._routes = list(routes or [])
+        self.name = name
+        self.path_regex, self.path_format, self.param_convertors = compile_path(self.path + "/{path:path}")
+
+        if middleware:
+            self.app = apply_middleware(self.app, middleware)
+
+    @property
+    def routes(self) -> list[routing.BaseRoute]:
+        return self._routes
+
+
+class Host(routing.Host):
+    def __init__(self, host: str, app: ASGIApp, name: str = None, *, middleware: t.Sequence[Middleware] = None) -> None:
+        self.host = host
+        self.app = app
+        self.name = name
+        self.host_regex, self.host_format, self.param_convertors = compile_path(host)
+        self.middleware = middleware
+        self._routes = getattr(app, 'routes', [])
+
+        if middleware:
+            self.app = apply_middleware(self.app, middleware)
+
+    @property
+    def routes(self) -> list[routing.BaseRoute]:
+        return self._routes
+
+
 class Router(routing.Router):
     pass
 
@@ -56,11 +102,11 @@ class Route(routing.Route):
     def __init__(
         self,
         path: str,
-        endpoint: typing.Callable,
+        endpoint: t.Callable,
         *,
         name: str = None,
         include_in_schema: bool = True,
-        methods: typing.List[str] = None,
+        methods: list[str] = None,
         middleware: t.Sequence[Middleware] = None,
     ) -> None:
         assert path.startswith("/"), "Routed paths must start with '/'"
@@ -99,26 +145,13 @@ class Route(routing.Route):
 
 class _RouteAdapter:
     _routes: Routes
-    _wrapped_app: t.Optional[ASGIApp]
     _base_app: t.Optional[ASGIApp]
-    _middleware: t.Sequence[Middleware]
-
-    async def handle(self, scope: Scope, receive: Receive, send: Send) -> None:
-        assert self._wrapped_app  # silence mypy
-        await self._wrapped_app(scope, receive, send)
-
-    def _initialize_apps(self) -> None:
-        self._base_app = self._create_base_asgi_app()
-        self._wrapped_app = self._apply_middleware(self._base_app)
 
     def _create_base_asgi_app(self) -> ASGIApp:
         raise NotImplementedError()
 
-    def _apply_middleware(self, app: ASGIApp) -> ASGIApp:
-        return apply_middleware(app, self._middleware)
-
     def __enter__(self) -> Routes:
-        self._wrapped_app = None  # force app recreation when routes changed
+        self._base_app = None  # force app recreate when routes change
         return self._routes
 
     def __exit__(self, *args: t.Any) -> None:
@@ -128,7 +161,7 @@ class _RouteAdapter:
         try:
             return getattr(self._base_app, item)
         except AttributeError:
-            self._initialize_apps()
+            self._base_app = self._create_base_asgi_app()
             return getattr(self._base_app, item)
 
 
@@ -145,10 +178,10 @@ class HostRoutes(_RouteAdapter):
         self._routes = Routes(routes)
         self._middleware = middleware or []
         self._wrapped_app: t.Optional[ASGIApp] = None
-        self._base_app: t.Optional[routing.Host] = None
+        self._base_app: t.Optional[Host] = None
 
     def _create_base_asgi_app(self) -> ASGIApp:
-        return routing.Host(host=self._host, app=Router(routes=self._routes), name=self._name)
+        return Host(host=self._host, app=Router(routes=self._routes), name=self._name, middleware=self._middleware)
 
 
 class GroupRoutes(_RouteAdapter):
@@ -164,21 +197,10 @@ class GroupRoutes(_RouteAdapter):
         self._routes = Routes(routes)
         self._middleware = middleware or []
         self._wrapped_app: t.Optional[ASGIApp] = None
-        self._base_app: t.Optional[routing.Mount] = None
-
-    def _apply_middleware(self, app: ASGIApp) -> ASGIApp:
-        return app
+        self._base_app: t.Optional[Mount] = None
 
     def _create_base_asgi_app(self) -> ASGIApp:
-        router: ASGIApp = Router(self._routes)
-        if self._middleware:
-            for mw in reversed(self._middleware):
-                router = mw.wrap(router)
-        return routing.Mount(path=self._prefix, app=router, name=self._name)
-
-    async def handle(self, scope: Scope, receive: Receive, send: Send) -> None:
-        assert self._base_app  # silence mypy
-        await self._base_app.handle(scope, receive, send)
+        return Mount(path=self._prefix, routes=self._routes, name=self._name, middleware=self._middleware)
 
 
 class ResourceRoute(routing.BaseRoute):
